
#include "interrupt.h"
#include "stm32f4xx_tim.h"

extern xQueueHandle xQueueCAN2,xQueueCAN1;



/**
  * @brief  Configures the NVIC.
  * @param  None
  * @retval None
  */
void InterruptCAN_Init(void)
{
  NVIC_InitTypeDef NVIC_InitStructure;

  NVIC_InitStructure.NVIC_IRQChannel = CAN2_RX0_IRQn;

  NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0;
  NVIC_InitStructure.NVIC_IRQChannelSubPriority =configMAX_SYSCALL_INTERRUPT_PRIORITY+1;
  NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;

  NVIC_Init(&NVIC_InitStructure);

  NVIC_InitStructure.NVIC_IRQChannel = CAN1_RX1_IRQn;

  NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0;
  NVIC_InitStructure.NVIC_IRQChannelSubPriority =configMAX_SYSCALL_INTERRUPT_PRIORITY+1;
  NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;

  NVIC_Init(&NVIC_InitStructure);
}

/**
  * @brief  ISR welche nach Empfang einer CAN Frame von CAN2 aufgerufen wird. Die ISR
  * 		Kopiert die CAN Frame in die Queue welche von dann von einer Task ausgelesen wird.
  * @param  None
  * @retval None
  */
void CAN2_RX0_IRQHandler(void)
{
  CanRxMsg RxMessage;
  portBASE_TYPE xHigherPriorityTaskWoken;

  xHigherPriorityTaskWoken = pdFALSE;

  CAN_Receive(CAN2, CAN_FIFO0, &RxMessage);

  xQueueSendToFrontFromISR( xQueueCAN2, &RxMessage, &xHigherPriorityTaskWoken );

  if( xHigherPriorityTaskWoken ==pdTRUE )
  	{
	  portYIELD();
  	}

}


/**
  * @brief  ISR welche nach Empfang einer CAN Frame von CAN1 aufgerufen wird. Die ISR
  * 		Kopiert die CAN Frame in die Queue welche von dann von einer Task ausgelesen wird.
  * @param  None
  * @retval None
  */
void CAN1_RX1_IRQHandler(void)
{
  CanRxMsg RxMessage;
  portBASE_TYPE xHigherPriorityTaskWoken;

  CAN_Receive(CAN1, CAN_FIFO1, &RxMessage);

  xQueueSendToFrontFromISR( xQueueCAN1, &RxMessage, &xHigherPriorityTaskWoken );

  if( xHigherPriorityTaskWoken ==pdTRUE )
  	{
	  portYIELD();
  	}



}

