/**
  ******************************************************************************
  * @file    main.c
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    31-October-2011
  * @brief   Main program body
  ******************************************************************************
  * @attention
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2011 STMicroelectronics</center></h2>
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/

#include <stdio.h>
#include "main.h"

/* Exported functions ---------------------------------------------------------*/
extern  uint8_t CAN_Send(CAN_TypeDef *CAN,CanTxMsg *Message);

/* Global Variables ---------------------------------------------------------*/
xQueueHandle xQueueCAN2,xQueueCAN1;

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/

/*--------------- Tasks Priority -------------*/
#define REC_TASK_PRIO   ( tskIDLE_PRIORITY + 2 )
#define SEND_TASK_PRIO    ( tskIDLE_PRIORITY + 1 )
#define polynom 0x09

/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/

/* Private function prototypes -----------------------------------------------*/
void LED_Init(void);

/* Private functions ---------------------------------------------------------*/

//Message.RTR = CAN_RTR_DATA	-> diese Frame eine Data Frame ist und KEINE Remote Frame
//Message.IDE = CAN_ID_STD		-> diese Frame eine Standart Id verwendet und KEIN Extended Id
//Message.StdId = 0x007			-> die Id dieser Frame ist  007 HEX
//Message.DLC = 8				-> diese Frame hat 8 Daten Bytes
//Message.Data[i] =0x55			-> das i-te Daten Byte hat den Wert 55 HEX

/**
  * @brief  Diese Task soll alle 5ms eine CAN Frame absenden. Dabei sind die Frames selbst
  * 		m�glichst kurz zu halten
  * @param  pvParameters not used
  * @retval None
  */
void PeriodicSend(void * pvParameters)
{
    CanTxMsg Message;
	static portTickType xLastWakeTime;

	xLastWakeTime = xTaskGetTickCount();

	  Message.StdId = 0x010;
	  Message.RTR 	= CAN_RTR_DATA;
	  Message.IDE 	= CAN_ID_STD;
	  Message.DLC 	= 1;

      for( ;; )
      {

    	/* toggle LED each 250ms */
    	GPIO_ToggleBits(GPIOD, GPIO_Pin_13);

    	/*     	Message.StdId = 0x111 		=> ID der Frame
    	 * 		Message.Data[0]= 0x54		=> Daten des ersten Bytes (DLC = 1)
    	 *		CAN_Send(CAN1,&Message)		=> Nachricht wird�ber CAN1 versendet
    	 * 		vTaskDelay(5)				=> 5ms warten
    	 */
    	//-------------------------------------
    	//Hier Code einfügen
    	//-------------------------------------





    	//-------------------------------------


    	/*Wait for 100ms since LastWakeTime*/
    	vTaskDelayUntil( &xLastWakeTime, 100 );


      }


}
/**
  * @brief  Diese Task wird immer aufgerufen wenn eine CAN Frame von CAN1 empfangen wurde.
  * 		Als reaktion darauf wird die rote LED ein/ausgeschaltet
  * @param  pvParameters not used
  * @retval None
  */
void CAN1_MessageReceived ( void * pvParameters )
{

    CanRxMsg RxMessage;

    for(;;)
    {

    	xQueueReceive( xQueueCAN1, &( RxMessage ), portMAX_DELAY );
    	GPIO_ToggleBits(GPIOD, GPIO_Pin_14);

    }

}

/**
  * @brief  Diese Task wird immer aufgerufen wenn eine CAN Frame von CAN2 empfangen wurde.
  * 		Als Reaktion darauf wird die gr�ne LED ein/ausgeschaltet.
  * @param  pvParameters not used
  * @retval None
  */
void CAN2_MessageReceived ( void * pvParameters )
{

    CanRxMsg RxMessage;

    for(;;)
    {

    	xQueueReceive( xQueueCAN2, &( RxMessage ), portMAX_DELAY );
    	GPIO_ToggleBits(GPIOD, GPIO_Pin_12);

    	//Die ID der empfangenen Frame wird ge�ndert und �ber CAN2
    	//zur�ckgeschickt

    	//RxMessage.StdId=0x112;
    	//CAN_Send(CAN2,&RxMessage);
    }

}

/**
  * @brief  Main program anfangs werden alle Peripherien initialisiert
  * 		danach werden die Tasks erzeugt. Kurz bevor das Betriebssystem
  * 		gestartet wird, werden noch die CAN interrupts scharf geschaltet.
  * @param  None
  * @retval None
  */
int main(void)
{
	portBASE_TYPE periodicSend = 0;
	portBASE_TYPE can1MessageReceived = 0;
	portBASE_TYPE can2MessageReceived = 0;
	int8_t checkTasks = 0;
	int8_t numTasks = 3;
	int32_t pauseValue;
	SystemInit();
	/*!< At this stage the microcontroller clock setting is already configured to
	   168 MHz, this is done through SystemInit() function which is called from
	   startup file (startup_stm32f4xx.s) before to branch to application main.
	   To reconfigure the default setting of SystemInit() function, refer to
	   system_stm32f4xx.c file
	 */

	/*Initialize Leds */
	LED_Init();

	/*Configure the Interrupt*/
	InterruptCAN_Init();

	CAN_Initialisierung();

	/*Create the Queues who are used in the Tasks*/
	xQueueCAN2 = xQueueCreate( 1, sizeof( CanRxMsg ) );
	xQueueCAN1 = xQueueCreate( 1, sizeof( CanRxMsg ) );

	/*was the Queues successful created*/
	if( xQueueCAN2 == 0 || xQueueCAN1 == 0 )
	{
		while(1)
		;
	}

	/* Create Tasks */
	periodicSend = xTaskCreate( PeriodicSend, NULL, configMINIMAL_STACK_SIZE, NULL, SEND_TASK_PRIO, NULL);
	can1MessageReceived = xTaskCreate( CAN1_MessageReceived ,NULL, configMINIMAL_STACK_SIZE, NULL, REC_TASK_PRIO, NULL );
	can2MessageReceived = xTaskCreate( CAN2_MessageReceived ,NULL, configMINIMAL_STACK_SIZE, NULL, REC_TASK_PRIO, NULL );

	checkTasks = periodicSend + can1MessageReceived + can2MessageReceived;

	if(checkTasks != numTasks)
	{
		GPIO_SetBits(GPIOD, GPIO_Pin_15);
		GPIO_SetBits(GPIOD, GPIO_Pin_14);
		GPIO_SetBits(GPIOD, GPIO_Pin_13);
		GPIO_SetBits(GPIOD, GPIO_Pin_12);
		while(1)
		{
			for(pauseValue=0; pauseValue<1000000; pauseValue++);
			GPIO_ToggleBits(GPIOD, GPIO_Pin_15);
			GPIO_ToggleBits(GPIOD, GPIO_Pin_14);
			GPIO_ToggleBits(GPIOD, GPIO_Pin_13);
			GPIO_ToggleBits(GPIOD, GPIO_Pin_12);
		}
	}

	/*Enable CAN Interrupt*/
	CAN_ITConfig(CAN2, CAN_IT_FMP0, ENABLE);
	/*Enable CAN Interrupt*/
	CAN_ITConfig(CAN1, CAN_IT_FMP1, ENABLE);

	/* Start scheduler */
	vTaskStartScheduler();

	/* We should never get here as control is now taken by the scheduler */
	for( ;; );
}



/**
  * @brief  Initializes the LEDs resources.
  * @param  None
  * @retval None
  */
void LED_Init(void)
{
	GPIO_InitTypeDef GPIO_InitStructure;

  /* Initialize Discovery's LEDs */
  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOD, ENABLE);

  /* Configure LEDs in Output-Pushpull-Mode */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_12 | GPIO_Pin_13 | GPIO_Pin_14 | GPIO_Pin_15;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;
  GPIO_Init(GPIOD, &GPIO_InitStructure);


}




/******************* (C) COPYRIGHT 2011 STMicroelectronics *****END OF FILE****/
